@@ -21,14 +21,11 @@ import (
 	"context"
 	"errors"
 	"fmt"
-	"go/constant"
 	"go/types"
 	"log"
 	"os"
 	"path"
-	"path/filepath"
 	"reflect"
-	"strconv"
 	"strings"
 
 	"github.com/goplus/gop/ast"
@@ -60,6 +57,18 @@ func SetDebug(flags int) {
 	debugLookup = (flags & DbgFlagLookup) != 0
 }
 
+type Errors struct {
+	Errs []error
+}
+
+func (p *Errors) Error() string {
+	msgs := make([]string, len(p.Errs))
+	for i, err := range p.Errs {
+		msgs[i] = err.Error()
+	}
+	return strings.Join(msgs, "\n")
+}
+
 // -----------------------------------------------------------------------------
 
 // Config of loading Go+ packages.
@@ -266,238 +275,6 @@ func doInitMethods(ld *typeLoader) {
 	}
 }
 
-type Errors struct {
-	Errs []error
-}
-
-func (p *Errors) Error() string {
-	msgs := make([]string, len(p.Errs))
-	for i, err := range p.Errs {
-		msgs[i] = err.Error()
-	}
-	return strings.Join(msgs, "\n")
-}
-
-type gmxSettings struct {
-	Pkg    string
-	Class  string
-	This   string
-	spx    *gox.PkgRef
-	game   gox.Ref
-	sprite gox.Ref
-	titles []string
-	params map[string][]*ast.Field
-}
-
-func newGmx(pkg *gox.Package, file string, gmx *ast.File) *gmxSettings {
-	p := &gmxSettings{Pkg: "github.com/goplus/spx", Class: getDefaultClass(file), This: "this"}
-	getGameSettings(gmx, p)
-	p.spx = pkg.Import(p.Pkg)
-	p.game = spxRef(p.spx, "Gop_game", "Game")
-	p.sprite = spxRef(p.spx, "Gop_sprite", "Sprite")
-	p.titles = getStrings(p.spx, "Gop_title")
-	p.params = getParams(p.spx, "Gop_params")
-	return p
-}
-
-func (p *gmxSettings) addParams(name string, typ *ast.FuncType) {
-	if params, ok := p.params[name]; ok {
-		list := typ.Params.List
-		if i := len(list); i < len(params) {
-			if params[i] == nil {
-				panic("addParams: no default param")
-			}
-			typ.Params.List = append(list, params[i:]...)
-		}
-	}
-}
-
-func (p *gmxSettings) toTitle(v *ast.Ident) {
-	name := v.Name
-	for _, t := range p.titles {
-		if strings.HasPrefix(name, t) {
-			v.Name = strings.Title(t) + name[len(t):]
-		}
-	}
-}
-
-func getDefaultClass(file string) string {
-	_, name := filepath.Split(file)
-	if idx := strings.Index(name, "."); idx > 0 {
-		name = name[:idx]
-	}
-	return name
-}
-
-func spxRef(spx *gox.PkgRef, name, typ string) gox.Ref {
-	if v := getStringConst(spx, name); v != "" {
-		typ = v
-	}
-	return spx.Ref(typ)
-}
-
-// onMsg(, _gop_data interface{}); onCloned(_gop_data interface{})
-func getParams(spx *gox.PkgRef, name string) map[string][]*ast.Field {
-	ret := map[string][]*ast.Field{}
-	if v := getStringConst(spx, name); v != "" {
-		for _, part := range strings.Split(v, ";") {
-			part = strings.TrimPrefix(part, " ")
-			pos := strings.Index(part, "(")
-			pos2 := strings.Index(part, ")")
-			if pos > 0 && pos2 == len(part)-1 {
-				key := part[:pos]
-				params := strings.Split(part[pos+1:pos2], ",")
-				tuple := make([]*ast.Field, len(params))
-				for i, param := range params {
-					param = strings.TrimPrefix(param, " ")
-					tuple[i] = getField(param)
-				}
-				ret[key] = tuple
-			}
-		}
-	}
-	return ret
-}
-
-// _gop_data interface{}
-func getField(param string) *ast.Field {
-	if param == "" {
-		return nil
-	}
-	idx := strings.Index(param, " ")
-	if idx > 0 {
-		name := param[:idx]
-		if typ, ok := strTypes[param[idx+1:]]; ok {
-			return &ast.Field{
-				Names: []*ast.Ident{{Name: name}},
-				Type:  typ,
-			}
-		}
-	}
-	panic("getVar failed: " + param)
-}
-
-var (
-	strTypes = map[string]ast.Expr{
-		"interface{}": &ast.InterfaceType{Methods: &ast.FieldList{}},
-		"string":      &ast.Ident{Name: "string"},
-		"int":         &ast.Ident{Name: "int"},
-	}
-)
-
-// on,off
-func getStrings(spx *gox.PkgRef, name string) []string {
-	if v := getStringConst(spx, name); v != "" {
-		return strings.Split(v, ",")
-	}
-	return nil
-}
-
-func getStringConst(spx *gox.PkgRef, name string) string {
-	if o := spx.Ref(name); o != nil {
-		if c, ok := o.(*types.Const); ok {
-			return constant.StringVal(c.Val())
-		}
-	}
-	return ""
-}
-
-func getStringVal(v ast.Expr, ret *string) {
-	if lit, ok := v.(*ast.BasicLit); ok && lit.Kind == token.STRING {
-		if val, err := strconv.Unquote(lit.Value); err == nil {
-			*ret = val
-		}
-	}
-}
-
-func getFields(ctx *blockCtx, f *ast.File) (specs []ast.Spec) {
-	decls := f.Decls
-	i, n := 0, len(decls)
-	for i < n {
-		g, ok := decls[i].(*ast.GenDecl)
-		if !ok {
-			break
-		}
-		if g.Tok != token.IMPORT && g.Tok != token.CONST {
-			if g.Tok == token.VAR {
-				specs, g.Specs = g.Specs, nil
-			}
-			break
-		}
-		i++ // skip import, if any
-	}
-	return
-}
-
-func getClass(file string, spx *ast.File) string {
-	decls := spx.Decls
-	i, n := 0, len(decls)
-	val := getDefaultClass(file)
-	for i < n {
-		g, ok := decls[i].(*ast.GenDecl)
-		if !ok {
-			break
-		}
-		if g.Tok != token.IMPORT {
-			if g.Tok == token.CONST {
-				rm := true
-				for _, v := range g.Specs {
-					spec := v.(*ast.ValueSpec)
-					for i, name := range spec.Names {
-						if name.Name == "GopClass" {
-							getStringVal(spec.Values[i], &val)
-						} else {
-							rm = false
-						}
-					}
-				}
-				if rm {
-					g.Specs = nil
-				}
-			}
-			break
-		}
-		i++ // skip import, if any
-	}
-	return val
-}
-
-func getGameSettings(gmx *ast.File, ret *gmxSettings) {
-	decls := gmx.Decls
-	i, n := 0, len(decls)
-	for i < n {
-		g, ok := decls[i].(*ast.GenDecl)
-		if !ok {
-			break
-		}
-		if g.Tok != token.IMPORT {
-			if g.Tok == token.CONST {
-				rm := true
-				for _, v := range g.Specs {
-					spec := v.(*ast.ValueSpec)
-					for i, name := range spec.Names {
-						switch name.Name {
-						case "GopGamePkg":
-							getStringVal(spec.Values[i], &ret.Pkg)
-						case "GopClass":
-							getStringVal(spec.Values[i], &ret.Class)
-						case "GopThis":
-							getStringVal(spec.Values[i], &ret.This)
-						default:
-							rm = false
-						}
-					}
-				}
-				if rm {
-					g.Specs = nil
-				}
-			}
-			break
-		}
-		i++ // skip import, if any
-	}
-}
-
 type pkgCtx struct {
 	*nodeInterp
 	*gmxSettings
@@ -513,6 +290,7 @@ type blockCtx struct {
 	cb           *gox.CodeBuilder
 	fset         *token.FileSet
 	imports      map[string]*gox.PkgRef
+	lookups      []*gox.PkgRef
 	targetDir    string
 	classRecv    *ast.FieldList // avaliable when gmxSettings != nil
 	fileLine     bool
@@ -631,7 +409,7 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 	p = gox.NewPackage(pkgPath, pkg.Name, confGox)
 	for file, gmx := range pkg.Files {
 		if gmx.FileType == ast.FileTypeGmx {
-			ctx.gmxSettings = newGmx(p, file, gmx)
+			ctx.gmxSettings = newGmx(p, file)
 			break
 		}
 	}
@@ -641,13 +419,7 @@ func NewPackage(pkgPath string, pkg *ast.Package, conf *Config) (p *gox.Package,
 	for _, f := range pkg.Files {
 		if f.FileType == ast.FileTypeGmx {
 			loadFile(ctx, f)
-			if o := p.Types.Scope().Lookup(ctx.Class); o != nil && hasMethod(o, "Main") {
-				// new(Game).main()
-				p.NewFunc(nil, "main", nil, nil, false).BodyStart(p).
-					Val(p.Builtin().Ref("new")).Val(o).Call(1).
-					MemberVal("Main").Call(0).EndStmt().
-					End()
-			}
+			gmxMainFunc(p, ctx)
 			break
 		}
 	}
@@ -723,18 +495,22 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 	switch f.FileType {
 	case ast.FileTypeSpx:
 		if parent.gmxSettings != nil {
-			classType = getClass(file, f)
+			classType = getDefaultClass(file)
 			baseType = parent.sprite
 		}
 		// TODO: panic
 	case ast.FileTypeGmx:
-		classType = parent.Class
+		classType = parent.gameClass
 		baseType = parent.game
 	}
 	if classType != "" {
 		if debugLoad {
 			log.Println("==> Preload type", classType)
 		}
+		ctx.lookups = make([]*gox.PkgRef, len(parent.pkgPaths))
+		for i, pkgPath := range parent.pkgPaths {
+			ctx.lookups[i] = p.Import(pkgPath)
+		}
 		pos := f.Pos()
 		specs := getFields(ctx, f)
 		ld := getTypeLoader(syms, pos, classType)
@@ -751,7 +527,7 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 				flds := make([]*types.Var, 1, 2)
 				flds[0] = types.NewField(pos, pkg, baseType.Name(), baseType.Type(), true)
 				if f.FileType == ast.FileTypeSpx {
-					typ := toType(ctx, &ast.StarExpr{X: &ast.Ident{Name: parent.Class}})
+					typ := toType(ctx, &ast.StarExpr{X: &ast.Ident{Name: parent.gameClass}})
 					fld := types.NewField(pos, pkg, getTypeName(typ), typ, true)
 					flds = append(flds, fld)
 				}
@@ -768,7 +544,7 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 		}
 		ctx.classRecv = &ast.FieldList{List: []*ast.Field{{
 			Names: []*ast.Ident{
-				{Name: parent.This},
+				{Name: "this"},
 			},
 			Type: &ast.StarExpr{
 				X: &ast.Ident{Name: classType},
@@ -782,11 +558,8 @@ func preloadFile(p *gox.Package, parent *pkgCtx, file string, f *ast.File, targe
 				if d.Recv == nil {
 					name := d.Name.Name
 					d.Recv = ctx.classRecv
-					ctx.addParams(name, d.Type)
-					if f.NoEntrypoint && (name == "main") {
+					if f.NoEntrypoint && f.FileType == ast.FileTypeSpx && (name == "main") {
 						d.Name.Name = "Main"
-					} else { // onMsg => OnMsg, etc
-						ctx.toTitle(d.Name)
 					}
 				}
 			}
@@ -1014,7 +787,8 @@ func loadImport(ctx *blockCtx, spec *ast.ImportSpec) {
 	if spec.Name != nil {
 		name = spec.Name.Name
 		if name == "." {
-			panic("TODO: not impl")
+			ctx.lookups = append(ctx.lookups, pkg)
+			return
 		}
 		if name == "_" {
 			pkg.MarkForceUsed()
