@@ -2315,11 +2315,22 @@ var d = a.Gop_Neg()
 `)
 }
 
+func TestCmdlineNoEOL(t *testing.T) {
+	gopClTest(t, `println "Hi"`, `package main
+
+import fmt "fmt"
+
+func main() {
+	fmt.Println("Hi")
+}
+`)
+}
+
 func TestImport(t *testing.T) {
 	gopClTest(t, `import "fmt"
 
 func main() {
-	fmt.Println("Hi")
+	fmt.println "Hi"
 }`, `package main
 
 import fmt "fmt"
@@ -2330,6 +2341,26 @@ func main() {
 `)
 }
 
+func TestDotImport(t *testing.T) {
+	gopClTest(t, `import . "math"
+
+var a = round(1.2)
+`, `package main
+
+import math "math"
+
+var a = math.Round(1.2)
+`)
+}
+
+func _TestLocalImport(t *testing.T) {
+	gopClTest(t, `import "./internal/spx"
+
+var a = spx.TestIntValue
+`, `
+`)
+}
+
 func TestImportUnused(t *testing.T) {
 	gopClTest(t, `import "fmt"
 
