@@ -108,11 +108,9 @@ func compileIdent(ctx *blockCtx, ident *ast.Ident, flags int) *gox.PkgRef {
 		}
 	}
 
-	// spx object
-	if ctx.fileType > 0 {
-		if compilePkgRef(ctx, ctx.spx, ident, (flags&clIdentLHS) != 0) {
-			return nil
-		}
+	// object from import . "xxx"
+	if compilePkgRef(ctx, nil, ident, flags) {
+		return nil
 	}
 
 	// universe object
@@ -310,7 +308,7 @@ func compileSelectorExpr(ctx *blockCtx, v *ast.SelectorExpr, flags int) {
 	switch x := v.X.(type) {
 	case *ast.Ident:
 		if at := compileIdent(ctx, x, flags|clIdentSelectorExpr); at != nil {
-			if compilePkgRef(ctx, at, v.Sel, false) {
+			if compilePkgRef(ctx, at, v.Sel, flags) {
 				return
 			}
 			if token.IsExported(v.Sel.Name) {
@@ -326,28 +324,53 @@ func compileSelectorExpr(ctx *blockCtx, v *ast.SelectorExpr, flags int) {
 	}
 }
 
-func compilePkgRef(ctx *blockCtx, at *gox.PkgRef, name *ast.Ident, lhs bool) bool {
-	v := pkgRef(at, name.Name)
-	if v == nil {
-		return false
-	}
-	if lhs {
-		ctx.cb.VarRef(v, name)
-	} else {
-		ctx.cb.Val(v, name)
-	}
-	return true
-}
-
-func pkgRef(at *gox.PkgRef, name string) gox.Ref {
-	if o := at.Ref(name); o != nil {
-		return o
-	}
+func pkgRef(at *gox.PkgRef, name string) (o types.Object, canAutoCall bool) {
 	if c := name[0]; c >= 'a' && c <= 'z' {
 		name = string(rune(c)+('A'-'a')) + name[1:]
-		return at.Ref(name)
+		return at.Ref(name), true
 	}
-	return nil
+	return at.Ref(name), false
+}
+
+func lookupPkgRef(ctx *blockCtx, pkg *gox.PkgRef, x *ast.Ident) (o types.Object, canAutoCall bool) {
+	if pkg != nil {
+		return pkgRef(pkg, x.Name)
+	}
+	for _, at := range ctx.lookups {
+		if o2, canAutoCall2 := pkgRef(at, x.Name); o2 != nil {
+			if o != nil {
+				panic(ctx.newCodeErrorf(
+					x.Pos(), "confliction: %s declared both in \"%s\" and \"%s\"",
+					x.Name, at.Types.Path(), pkg.Types.Path()))
+			}
+			pkg, o, canAutoCall = at, o2, canAutoCall2
+		}
+	}
+	return
+}
+
+func compilePkgRef(ctx *blockCtx, at *gox.PkgRef, x *ast.Ident, flags int) bool {
+	if v, canAutoCall := lookupPkgRef(ctx, at, x); v != nil {
+		cb := ctx.cb
+		if (flags & clIdentLHS) != 0 {
+			cb.VarRef(v, x)
+		} else {
+			cb.Val(v, x)
+			if canAutoCall && (flags&clIdentAutoCall) != 0 && isFunc(v.Type()) {
+				cb.Call(0)
+			}
+		}
+		return true
+	}
+	return false
+}
+
+func isFunc(typ types.Type) bool {
+	switch typ.(type) {
+	case *types.Signature:
+		return true
+	}
+	return false
 }
 
 type fnType struct {
