@@ -1337,8 +1337,18 @@ func (p *parser) isCommand(x ast.Expr) bool {
 		return false
 	}
 	switch p.tok {
-	case token.IDENT, token.RARROW, token.STRING, token.INT, token.FLOAT, token.IMAG, token.CHAR, token.RAT:
+	case token.IDENT, token.RARROW,
+		token.STRING, token.INT, token.FLOAT, token.IMAG, token.CHAR, token.RAT:
 		return true
+	case token.SUB, token.NOT, token.AND, token.MUL, token.ARROW, token.XOR, token.ADD:
+		if x.End() == p.pos { // x-y
+			return false
+		}
+		oldtok, oldpos := p.tok, p.pos
+		p.next()
+		newpos := int(p.pos)
+		p.unget(oldpos, oldtok, "")
+		return int(oldpos)+len(oldtok.String()) == newpos // x -y
 	}
 	return false
 }
@@ -1927,7 +1937,28 @@ func (p *parser) parseUnaryExpr(lhs, allowTuple, allowCmd bool) ast.Expr {
 		return &ast.StarExpr{Star: pos, X: p.checkExprOrType(x)}
 	}
 
-	return p.parsePrimaryExpr(lhs, allowTuple, allowCmd)
+	return p.parseErrWrapExpr(lhs, allowTuple, allowCmd)
+}
+
+// parseErrWrapExpr: expr! expr? expr?:defval
+func (p *parser) parseErrWrapExpr(lhs, allowTuple, allowCmd bool) ast.Expr {
+	x := p.parsePrimaryExpr(lhs, allowTuple, allowCmd)
+	switch p.tok {
+	case token.NOT: // expr!
+		expr := &ast.ErrWrapExpr{X: x, Tok: token.NOT, TokPos: p.pos}
+		p.next()
+		return expr
+	case token.QUESTION: // expr? expr?:defval
+		expr := &ast.ErrWrapExpr{X: x, Tok: token.QUESTION, TokPos: p.pos}
+		p.next()
+		if p.tok == token.COLON {
+			p.next()
+			expr.Default = p.parseUnaryExpr(false, true, false)
+		}
+		return expr
+	default:
+		return x
+	}
 }
 
 func (p *parser) tokPrec() (token.Token, int) {
@@ -1944,7 +1975,7 @@ func (p *parser) parseBinaryExpr(lhs bool, prec1 int, allowTuple, allowCmd bool)
 		defer un(trace(p, "BinaryExpr"))
 	}
 
-	x := p.parseErrWrapExpr(lhs, allowTuple, allowCmd) // TODO: change priority level of ErrWrapExpr
+	x := p.parseUnaryExpr(lhs, allowTuple, allowCmd)
 	for {
 		op, oprec := p.tokPrec()
 		if oprec < prec1 {
@@ -1960,26 +1991,6 @@ func (p *parser) parseBinaryExpr(lhs bool, prec1 int, allowTuple, allowCmd bool)
 	}
 }
 
-func (p *parser) parseErrWrapExpr(lhs, allowTuple, allowCmd bool) ast.Expr { // expr! expr? expr?:defval
-	x := p.parseUnaryExpr(lhs, allowTuple, allowCmd)
-	switch p.tok {
-	case token.NOT: // expr!
-		expr := &ast.ErrWrapExpr{X: x, Tok: token.NOT, TokPos: p.pos}
-		p.next()
-		return expr
-	case token.QUESTION: // expr? expr?:defval
-		expr := &ast.ErrWrapExpr{X: x, Tok: token.QUESTION, TokPos: p.pos}
-		p.next()
-		if p.tok == token.COLON {
-			p.next()
-			expr.Default = p.parseUnaryExpr(false, true, false)
-		}
-		return expr
-	default:
-		return x
-	}
-}
-
 type tupleExpr struct {
 	ast.Expr
 	items []*ast.Ident
